@@ -65,18 +65,10 @@ typedef struct _XfsmClientClass
   XfsmDbusClientSkeletonClass parent;
 } XfsmClientClass;
 
-typedef struct
-{
-  SmProp *props;
-  gint    count;
-} HtToPropsData;
-
 
 
 static void xfsm_client_finalize (GObject *obj);
 
-static void    xfsm_properties_discard_command_changed (XfsmProperties *properties,
-                                                        gchar         **old_discard);
 static void    xfsm_client_dbus_class_init (XfsmClientClass *klass);
 static void    xfsm_client_dbus_init (XfsmClient *client);
 static void    xfsm_client_iface_init (XfsmDbusClientIface *iface);
@@ -145,6 +137,7 @@ get_state (XfsmClientState state)
   return client_state[state];
 }
 
+#ifdef ENABLE_X11
 static void
 xfsm_properties_discard_command_changed (XfsmProperties *properties,
                                          gchar         **old_discard)
@@ -206,9 +199,51 @@ xfsm_client_signal_prop_change (XfsmClient *client,
       g_variant_unref (variant);
     }
 }
+#endif
 
 
 
+gchar *
+xfsm_client_generate_id (SmsConn sms_conn)
+{
+  static char *addr = NULL;
+  static int   sequence = 0;
+  char        *id = NULL;
+
+#ifdef ENABLE_X11
+  if (sms_conn != NULL)
+    {
+      char *sms_id = SmsGenerateClientID (sms_conn);
+      if (sms_id != NULL)
+        {
+          id = g_strdup (sms_id);
+          g_free (sms_id);
+        }
+    }
+#endif
+
+  if (id == NULL)
+    {
+      if (addr == NULL)
+        {
+          /*
+           * Faking our IP address, the 0 below is "unknown"
+           * address format (1 would be IP, 2 would be DEC-NET
+           * format). Stolen from KDE :-)
+           */
+          addr = g_strdup_printf ("0%.8x", g_random_int ());
+        }
+
+      id = (char *) g_malloc (50);
+      g_snprintf (id, 50, "1%s%.13ld%.10d%.4d", addr,
+                  (long) time (NULL), (int) getpid (), sequence);
+      sequence = (sequence + 1) % 10000;
+    }
+
+  return id;
+}
+
+
 XfsmClient*
 xfsm_client_new (XfsmManager *manager,
                  SmsConn      sms_conn,
@@ -348,6 +383,7 @@ xfsm_client_steal_properties (XfsmClient *client)
 }
 
 
+#ifdef ENABLE_X11
 void
 xfsm_client_merge_properties (XfsmClient *client,
                               SmProp    **props,
@@ -386,6 +422,7 @@ xfsm_client_merge_properties (XfsmClient *client,
       g_strfreev (old_discard);
     }
 }
+#endif
 
 
 void
