@@ -53,6 +53,8 @@ typedef enum
 
 GType xfsm_client_get_type (void) G_GNUC_CONST;
 
+gchar *xfsm_client_generate_id (SmsConn sms_conn) G_GNUC_PURE;
+
 XfsmClient *xfsm_client_new (struct _XfsmManager *manager,
                              SmsConn              sms_conn,
                              GDBusConnection     *connection);
@@ -72,9 +74,11 @@ SmsConn xfsm_client_get_sms_connection (XfsmClient *client);
 XfsmProperties *xfsm_client_get_properties (XfsmClient *client);
 XfsmProperties *xfsm_client_steal_properties (XfsmClient *client);
 
+#ifdef ENABLE_X11
 void xfsm_client_merge_properties (XfsmClient *client,
                                    SmProp    **props,
                                    gint        num_props);
+#endif
 void xfsm_client_delete_properties (XfsmClient *client,
                                     gchar     **prop_names,
                                     gint        num_props);
