@@ -44,7 +44,6 @@
 #endif
 
 #include <gtk/gtk.h>
-#include <gdk/gdkx.h>
 
 #include <libxfce4util/libxfce4util.h>
 
@@ -132,7 +131,7 @@ xfsm_compat_kde_startup (void)
   run (command);
 
   /* tell kde if we are running multi-head */
-  if (XScreenCount (gdk_x11_display_get_xdisplay (gdk_display_get_default ())) > 1)
+  if (gdk_display_get_n_screens (gdk_display_get_default ()) > 1)
     {
       g_snprintf (command, 256, "qdbus org.kde.klauncher /KLauncher setLaunchEnv "
                                 "KDE_MULTIHEAD \"true\"");
