@@ -45,6 +45,9 @@
 
 #include <libxfce4util/libxfce4util.h>
 #include <gtk/gtk.h>
+#ifdef HAVE_GTK_LAYER_SHELL
+#include <gtk-layer-shell/gtk-layer-shell.h>
+#endif
 
 #include <libxfsm/xfsm-util.h>
 
@@ -54,7 +57,7 @@
 #include <xfce4-session/xfsm-legacy.h>
 #include <xfce4-session/xfsm-error.h>
 
-#ifdef GDK_WINDOWING_X11
+#ifdef ENABLE_X11
 #include <X11/Xlib.h>
 #include <gdk/gdkx.h>
 #endif
@@ -95,9 +98,6 @@ struct _XfsmLogoutDialog
   /* set when a button is clicked */
   XfsmShutdownType  type_clicked;
 
-  /* save session checkbox */
-  GtkWidget        *save_session;
-
   /* mode widgets */
   GtkWidget        *box[N_MODES];
 
@@ -142,7 +142,6 @@ xfsm_logout_dialog_init (XfsmLogoutDialog *dialog)
   GtkWidget      *button;
   gboolean        can_shutdown = FALSE;
   gboolean        has_updates;
-  gboolean        save_session = FALSE;
   gboolean        can_logout = FALSE;
   gboolean        can_restart = FALSE;
   gboolean        can_suspend = FALSE;
@@ -160,6 +159,15 @@ xfsm_logout_dialog_init (XfsmLogoutDialog *dialog)
   GtkWidget      *separator;
   GtkCssProvider *provider;
 
+#ifdef HAVE_GTK_LAYER_SHELL
+  if (gtk_layer_is_supported ())
+    {
+      gtk_layer_init_for_window (GTK_WINDOW (dialog));
+      gtk_layer_set_keyboard_mode (GTK_WINDOW (dialog), GTK_LAYER_SHELL_KEYBOARD_MODE_EXCLUSIVE);
+      gtk_layer_set_layer (GTK_WINDOW (dialog), GTK_LAYER_SHELL_LAYER_OVERLAY);
+    }
+#endif
+
   dialog->type_clicked = XFSM_SHUTDOWN_LOGOUT;
   dialog->shutdown = xfsm_shutdown_get ();
 
@@ -176,11 +184,6 @@ xfsm_logout_dialog_init (XfsmLogoutDialog *dialog)
                                   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
   g_object_unref (provider);
 
-  /* load xfconf settings */
-  channel = xfconf_channel_get (SETTINGS_CHANNEL);
-  if (xfsm_shutdown_can_save_session (dialog->shutdown))
-    save_session = xfconf_channel_get_bool (channel, "/general/SaveOnExit", TRUE);
-
   main_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, BORDER);
   gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), main_vbox, TRUE, TRUE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (main_vbox), 12);
@@ -286,6 +289,8 @@ xfsm_logout_dialog_init (XfsmLogoutDialog *dialog)
   gtk_box_set_homogeneous (GTK_BOX (hbox), TRUE);
   gtk_box_pack_start (GTK_BOX (button_vbox), hbox, FALSE, TRUE, 0);
 
+  channel = xfconf_channel_get (SETTINGS_CHANNEL);
+
   /**
    * Suspend
    **/
@@ -376,19 +381,6 @@ xfsm_logout_dialog_init (XfsmLogoutDialog *dialog)
         }
     }
 
-  /**
-   * Save session
-   **/
-  if (xfsm_shutdown_can_save_session (dialog->shutdown)
-      && !xfconf_channel_get_bool (channel, "/general/AutoSave", FALSE)
-      && xfconf_channel_get_bool (channel, "/general/ShowSave", TRUE))
-    {
-      dialog->save_session = gtk_check_button_new_with_mnemonic (_("_Save session for future logins"));
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->save_session), save_session);
-      gtk_box_pack_start (GTK_BOX (vbox), dialog->save_session, FALSE, TRUE, BORDER);
-      gtk_widget_show (dialog->save_session);
-    }
-
   attrs = pango_attr_list_new ();
   pango_attr_list_insert (attrs, pango_attr_weight_new (PANGO_WEIGHT_BOLD));
 
@@ -679,13 +671,16 @@ xfsm_logout_dialog_run (GtkDialog *dialog,
           g_critical ("Failed to grab the keyboard for logout window");
         }
 
-#ifdef GDK_WINDOWING_X11
-      /* force input to the dialog */
-      gdk_x11_display_error_trap_push (gdk_display_get_default ());
-      XSetInputFocus (gdk_x11_get_default_xdisplay (),
-                      GDK_WINDOW_XID (window),
-                      RevertToParent, CurrentTime);
-      gdk_x11_display_error_trap_pop_ignored (gdk_display_get_default ());
+#ifdef ENABLE_X11
+      if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+        {
+          /* force input to the dialog */
+          gdk_x11_display_error_trap_push (gdk_display_get_default ());
+          XSetInputFocus (gdk_x11_get_default_xdisplay (),
+                          GDK_WINDOW_XID (window),
+                          RevertToParent, CurrentTime);
+          gdk_x11_display_error_trap_pop_ignored (gdk_display_get_default ());
+        }
 #endif
     }
 
@@ -702,7 +697,6 @@ xfsm_logout_dialog_run (GtkDialog *dialog,
 gboolean
 xfsm_logout_dialog (const gchar      *session_name,
                     XfsmShutdownType *return_type,
-                    gboolean         *return_save_session,
                     gboolean          accessibility)
 {
   gint              result;
@@ -711,31 +705,21 @@ xfsm_logout_dialog (const gchar      *session_name,
   GdkScreen        *screen;
   gint              monitor;
   GdkPixbuf        *screenshot = NULL;
+#ifdef ENABLE_X11
   XfsmFadeout      *fadeout = NULL;
+#endif
   XfsmLogoutDialog *xfsm_dialog;
   XfconfChannel    *channel = xfconf_channel_get (SETTINGS_CHANNEL);
-  gboolean          autosave;
-  XfsmShutdown     *shutdown;
   GdkDevice        *device;
   GdkSeat          *seat;
   gint              grab_count = 0;
 
   g_return_val_if_fail (return_type != NULL, FALSE);
-  g_return_val_if_fail (return_save_session != NULL, FALSE);
-
-  shutdown = xfsm_shutdown_get ();
-  if (xfsm_shutdown_can_save_session (shutdown))
-    autosave = xfconf_channel_get_bool (channel, "/general/AutoSave", FALSE);
-  else
-    autosave = FALSE;
-  g_object_unref (shutdown);
 
   /* check if we need to bother the user */
   if (!xfconf_channel_get_bool (channel, "/general/PromptOnLogout", TRUE))
     {
       *return_type = XFSM_SHUTDOWN_LOGOUT;
-      *return_save_session = autosave;
-
       return TRUE;
     }
 
@@ -785,8 +769,13 @@ xfsm_logout_dialog (const gchar      *session_name,
       if (xfconf_channel_get_bool (channel, "/general/ShowScreenshots", TRUE))
         screenshot = xfsm_logout_dialog_screenshot_new (screen);
 
-      /* display fadeout */
-      fadeout = xfsm_fadeout_new (gdk_screen_get_display (screen));
+#ifdef ENABLE_X11
+      if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+        {
+          /* display fadeout */
+          fadeout = xfsm_fadeout_new (gdk_screen_get_display (screen));
+        }
+#endif
 
       dialog = g_object_new (XFSM_TYPE_LOGOUT_DIALOG,
                              "type", GTK_WINDOW_POPUP,
@@ -817,30 +806,23 @@ xfsm_logout_dialog (const gchar      *session_name,
 
   gtk_widget_hide (dialog);
 
-  if (result == GTK_RESPONSE_OK)
+#ifdef ENABLE_X11
+  if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
     {
-      /* store autosave state */
-      if (autosave)
-        *return_save_session = TRUE;
-      else if (xfsm_dialog->save_session != NULL)
-        *return_save_session = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (xfsm_dialog->save_session));
-      else
-        *return_save_session = FALSE;
-
-      /* return the clicked action */
-      *return_type = xfsm_dialog->type_clicked;
+      if (fadeout != NULL)
+        xfsm_fadeout_destroy (fadeout);
     }
-
-  if (fadeout != NULL)
-    xfsm_fadeout_destroy (fadeout);
+#endif
 
   gtk_widget_destroy (dialog);
 
-  /* store channel settings if everything worked fine */
   if (result == GTK_RESPONSE_OK)
     {
+      /* return the clicked action */
+      *return_type = xfsm_dialog->type_clicked;
+
+      /* store channel settings if everything worked fine */
       xfconf_channel_set_string (channel, "/general/SessionName", session_name);
-      xfconf_channel_set_bool (channel, "/general/SaveOnExit", *return_save_session);
     }
 
   /* save the screenshot */
