@@ -61,12 +61,13 @@
 #include <xfce4-session/xfsm-shutdown.h>
 #include <xfce4-session/xfsm-compat-gnome.h>
 #include <xfce4-session/xfsm-compat-kde.h>
-#include <xfce4-session/xfsm-consolekit.h>
 #include <xfce4-session/xfsm-fadeout.h>
+#include <xfce4-session/xfsm-inhibition.h>
+#include <xfce4-session/xfsm-inhibitor.h>
 #include <xfce4-session/xfsm-global.h>
 #include <xfce4-session/xfsm-legacy.h>
-#include <xfce4-session/xfsm-systemd.h>
 #include <xfce4-session/xfsm-shutdown-fallback.h>
+#include <xfce4-session/xfsm-packagekit.h>
 
 
 
@@ -84,8 +85,12 @@ struct _XfsmShutdown
 {
   GObject __parent__;
 
-  XfsmSystemd    *systemd;
-  XfsmConsolekit *consolekit;
+  XfceSystemd    *systemd;
+  XfceConsolekit *consolekit;
+
+  XfsmInhibitor   *inhibitions;
+  XfceScreensaver *screensaver;
+  XfsmPackagekit  *packagekit;
 
   /* kiosk settings */
   gboolean        kiosk_can_shutdown;
@@ -118,9 +123,13 @@ xfsm_shutdown_init (XfsmShutdown *shutdown)
   shutdown->systemd = NULL;
 
   if (LOGIND_RUNNING())
-    shutdown->systemd = xfsm_systemd_get ();
+    shutdown->systemd = xfce_systemd_get ();
   else
-    shutdown->consolekit = xfsm_consolekit_get ();
+    shutdown->consolekit = xfce_consolekit_get ();
+
+  shutdown->inhibitions = xfsm_inhibitor_get ();
+  shutdown->screensaver = xfce_screensaver_new ();
+  shutdown->packagekit = xfsm_packagekit_get ();
 
   /* check kiosk */
   kiosk = xfce_kiosk_new ("xfce4-session");
@@ -142,6 +151,12 @@ xfsm_shutdown_finalize (GObject *object)
   if (shutdown->consolekit != NULL)
     g_object_unref (G_OBJECT (shutdown->consolekit));
 
+  if (shutdown->inhibitions != NULL)
+    g_object_unref (G_OBJECT (shutdown->inhibitions));
+
+  g_object_unref (G_OBJECT (shutdown->screensaver));
+  g_object_unref (G_OBJECT (shutdown->packagekit));
+
   (*G_OBJECT_CLASS (xfsm_shutdown_parent_class)->finalize) (object);
 }
 
@@ -231,14 +246,21 @@ xfsm_shutdown_try_restart (XfsmShutdown  *shutdown,
 
   if (shutdown->systemd != NULL)
     {
-      if (xfsm_systemd_try_restart (shutdown->systemd, NULL))
+      gboolean has_updates = FALSE;
+      if (xfsm_packagekit_has_update_prepared (shutdown->packagekit, &has_updates, NULL)
+          && has_updates)
+        {
+          xfsm_packagekit_try_trigger_restart (shutdown->packagekit, NULL);
+        }
+
+      if (xfce_systemd_reboot (shutdown->systemd, TRUE, NULL))
         {
           return TRUE;
         }
     }
   else if (shutdown->consolekit != NULL)
     {
-      if (xfsm_consolekit_try_restart (shutdown->consolekit, NULL))
+      if (xfce_consolekit_reboot (shutdown->consolekit, TRUE, NULL))
         {
           return TRUE;
         }
@@ -260,14 +282,28 @@ xfsm_shutdown_try_shutdown (XfsmShutdown  *shutdown,
 
   if (shutdown->systemd != NULL)
     {
-      if (xfsm_systemd_try_shutdown (shutdown->systemd, NULL))
+      gboolean has_updates = FALSE;
+      if (xfsm_packagekit_has_update_prepared (shutdown->packagekit, &has_updates, NULL)
+          && has_updates
+          && xfsm_packagekit_try_trigger_shutdown (shutdown->packagekit, NULL))
+        {
+          // To actually trigger the offline update, we need to
+          // reboot to do the upgrade. When the upgrade is complete,
+          // the computer will shut down automatically.
+          if (xfce_systemd_reboot (shutdown->systemd, TRUE, NULL))
+            {
+              return TRUE;
+            }
+        }
+
+      if (xfce_systemd_power_off (shutdown->systemd, TRUE, NULL))
         {
           return TRUE;
         }
     }
   else if (shutdown->consolekit != NULL)
     {
-      if (xfsm_consolekit_try_shutdown (shutdown->consolekit, NULL))
+      if (xfce_consolekit_power_off (shutdown->consolekit, TRUE, NULL))
         {
           return TRUE;
         }
@@ -278,7 +314,7 @@ xfsm_shutdown_try_shutdown (XfsmShutdown  *shutdown,
 
 
 
-typedef gboolean (*SleepFunc) (gpointer object, GError **);
+typedef gboolean (*SleepFunc) (gpointer object, gboolean polkit_interactive, GError **error);
 
 static gboolean
 try_sleep_method (gpointer  object,
@@ -287,7 +323,26 @@ try_sleep_method (gpointer  object,
   if (object == NULL)
     return FALSE;
 
-  return func (object, NULL);
+  return func (object, TRUE, NULL);
+}
+
+
+
+static gboolean
+lock_screen (XfsmShutdown *shutdown,
+             GError **error)
+{
+  XfconfChannel *channel;
+  gboolean ret = TRUE;
+
+  channel = xfconf_channel_get (SETTINGS_CHANNEL);
+  if (xfconf_channel_get_bool (channel, "/shutdown/LockScreen", FALSE))
+    ret = xfce_screensaver_lock (shutdown->screensaver);
+
+  if (!ret)
+    g_set_error (error, 1, 0, "Failed to lock the screen.");
+
+  return ret;
 }
 
 
@@ -298,13 +353,16 @@ xfsm_shutdown_try_suspend (XfsmShutdown  *shutdown,
 {
   g_return_val_if_fail (XFSM_IS_SHUTDOWN (shutdown), FALSE);
 
+  if (!lock_screen (shutdown, error))
+    return FALSE;
+
   /* Try each way to suspend - it will handle NULL.
    */
 
-  if (try_sleep_method (shutdown->systemd, (SleepFunc)xfsm_systemd_try_suspend))
+  if (try_sleep_method (shutdown->systemd, (SleepFunc)xfce_systemd_suspend))
     return TRUE;
 
-  if (try_sleep_method (shutdown->consolekit, (SleepFunc)xfsm_consolekit_try_suspend))
+  if (try_sleep_method (shutdown->consolekit, (SleepFunc)xfce_consolekit_suspend))
     return TRUE;
 
   return xfsm_shutdown_fallback_try_action (XFSM_SHUTDOWN_SUSPEND, error);
@@ -318,13 +376,16 @@ xfsm_shutdown_try_hibernate (XfsmShutdown  *shutdown,
 {
   g_return_val_if_fail (XFSM_IS_SHUTDOWN (shutdown), FALSE);
 
+  if (!lock_screen (shutdown, error))
+    return FALSE;
+
   /* Try each way to hibernate - it will handle NULL.
    */
 
-  if (try_sleep_method (shutdown->systemd, (SleepFunc)xfsm_systemd_try_hibernate))
+  if (try_sleep_method (shutdown->systemd, (SleepFunc)xfce_systemd_hibernate))
     return TRUE;
 
-  if (try_sleep_method (shutdown->consolekit, (SleepFunc)xfsm_consolekit_try_hibernate))
+  if (try_sleep_method (shutdown->consolekit, (SleepFunc)xfce_consolekit_hibernate))
     return TRUE;
 
   return xfsm_shutdown_fallback_try_action (XFSM_SHUTDOWN_HIBERNATE, error);
@@ -338,13 +399,16 @@ xfsm_shutdown_try_hybrid_sleep (XfsmShutdown  *shutdown,
 {
   g_return_val_if_fail (XFSM_IS_SHUTDOWN (shutdown), FALSE);
 
+  if (!lock_screen (shutdown, error))
+    return FALSE;
+
   /* Try each way to hybrid-sleep - it will handle NULL.
    */
 
-  if (try_sleep_method (shutdown->systemd, (SleepFunc)xfsm_systemd_try_hybrid_sleep))
+  if (try_sleep_method (shutdown->systemd, (SleepFunc)xfce_systemd_hybrid_sleep))
     return TRUE;
 
-  if (try_sleep_method (shutdown->consolekit, (SleepFunc)xfsm_consolekit_try_hybrid_sleep))
+  if (try_sleep_method (shutdown->consolekit, (SleepFunc)xfce_consolekit_hybrid_sleep))
     return TRUE;
 
   return xfsm_shutdown_fallback_try_action (XFSM_SHUTDOWN_HYBRID_SLEEP, error);
@@ -399,170 +463,196 @@ xfsm_shutdown_try_switch_user (XfsmShutdown  *shutdown,
 }
 
 
-gboolean
+void
 xfsm_shutdown_can_restart (XfsmShutdown  *shutdown,
                            gboolean      *can_restart,
-                           GError       **error)
+                           gboolean      *auth_restart)
 {
-  g_return_val_if_fail (XFSM_IS_SHUTDOWN (shutdown), FALSE);
+  g_return_if_fail (XFSM_IS_SHUTDOWN (shutdown));
+
+  if (xfsm_inhibitor_has_flags (shutdown->inhibitions, XFSM_INHIBITON_FLAG_LOGOUT))
+    {
+      *can_restart = FALSE;
+      return;
+    }
 
   if (!xfsm_shutdown_kiosk_can_shutdown (shutdown, NULL))
     {
       *can_restart = FALSE;
-      return TRUE;
+      return;
     }
 
   if (shutdown->systemd != NULL)
     {
-      if (xfsm_systemd_can_restart (shutdown->systemd, can_restart, NULL))
-        return TRUE;
+      if (xfce_systemd_can_reboot (shutdown->systemd, can_restart, auth_restart, NULL))
+        return;
     }
   else if (shutdown->consolekit != NULL)
     {
-      if (xfsm_consolekit_can_restart (shutdown->consolekit, can_restart, NULL))
-        return TRUE;
+      if (xfce_consolekit_can_reboot (shutdown->consolekit, can_restart, auth_restart, NULL))
+        return;
     }
 
   *can_restart = xfsm_shutdown_fallback_auth_restart ();
-  return TRUE;
+  if (auth_restart != NULL)
+    *auth_restart = *can_restart;
 }
 
 
 
-gboolean
+void
 xfsm_shutdown_can_shutdown (XfsmShutdown  *shutdown,
                             gboolean      *can_shutdown,
-                            GError       **error)
+                            gboolean      *auth_shutdown)
 {
-  g_return_val_if_fail (XFSM_IS_SHUTDOWN (shutdown), FALSE);
+  g_return_if_fail (XFSM_IS_SHUTDOWN (shutdown));
+
+  if (xfsm_inhibitor_has_flags (shutdown->inhibitions, XFSM_INHIBITON_FLAG_LOGOUT))
+    {
+      *can_shutdown = FALSE;
+      return;
+    }
 
   if (!xfsm_shutdown_kiosk_can_shutdown (shutdown, NULL))
     {
       *can_shutdown = FALSE;
-      return TRUE;
+      return;
     }
 
   if (shutdown->systemd != NULL)
     {
-      if (xfsm_systemd_can_shutdown (shutdown->systemd, can_shutdown, NULL))
-        return TRUE;
+      if (xfce_systemd_can_power_off (shutdown->systemd, can_shutdown, auth_shutdown, NULL))
+        return;
     }
   else if (shutdown->consolekit != NULL)
     {
-      if (xfsm_consolekit_can_shutdown (shutdown->consolekit, can_shutdown, NULL))
-        return TRUE;
+      if (xfce_consolekit_can_power_off (shutdown->consolekit, can_shutdown, auth_shutdown, NULL))
+        return;
     }
 
   *can_shutdown = xfsm_shutdown_fallback_auth_shutdown ();
-  return TRUE;
+  if (auth_shutdown != NULL)
+    *auth_shutdown = *can_shutdown;
 }
 
 
 
-gboolean
+void
 xfsm_shutdown_can_suspend (XfsmShutdown  *shutdown,
                            gboolean      *can_suspend,
-                           gboolean      *auth_suspend,
-                           GError       **error)
+                           gboolean      *auth_suspend)
 {
-  g_return_val_if_fail (XFSM_IS_SHUTDOWN (shutdown), FALSE);
+  g_return_if_fail (XFSM_IS_SHUTDOWN (shutdown));
+
+  if (xfsm_inhibitor_has_flags (shutdown->inhibitions, XFSM_INHIBITON_FLAG_SUSPEND))
+    {
+      *can_suspend = FALSE;
+      return;
+    }
 
   if (!xfsm_shutdown_kiosk_can_shutdown (shutdown, NULL))
     {
       *can_suspend = FALSE;
-      return TRUE;
+      return;
     }
 
   if (shutdown->systemd != NULL)
     {
-      if (xfsm_systemd_can_suspend (shutdown->systemd, can_suspend, auth_suspend, NULL))
+      if (xfce_systemd_can_suspend (shutdown->systemd, can_suspend, auth_suspend, NULL))
         {
-          return TRUE;
+          return;
         }
     }
   else if (shutdown->consolekit != NULL)
     {
-      if (xfsm_consolekit_can_suspend (shutdown->consolekit, can_suspend, auth_suspend, NULL))
+      if (xfce_consolekit_can_suspend (shutdown->consolekit, can_suspend, auth_suspend, NULL))
         {
-          return TRUE;
+          return;
         }
     }
 
   *can_suspend = xfsm_shutdown_fallback_can_suspend ();
   *auth_suspend = xfsm_shutdown_fallback_auth_suspend ();
-  return TRUE;
 }
 
 
 
-gboolean
+void
 xfsm_shutdown_can_hibernate (XfsmShutdown  *shutdown,
                              gboolean      *can_hibernate,
-                             gboolean      *auth_hibernate,
-                             GError       **error)
+                             gboolean      *auth_hibernate)
 {
-  g_return_val_if_fail (XFSM_IS_SHUTDOWN (shutdown), FALSE);
+  g_return_if_fail (XFSM_IS_SHUTDOWN (shutdown));
+
+  if (xfsm_inhibitor_has_flags (shutdown->inhibitions, XFSM_INHIBITON_FLAG_SUSPEND))
+    {
+      *can_hibernate = FALSE;
+      return;
+    }
 
   if (!xfsm_shutdown_kiosk_can_shutdown (shutdown, NULL))
     {
       *can_hibernate = FALSE;
-      return TRUE;
+      return;
     }
 
   if (shutdown->systemd != NULL)
     {
-      if (xfsm_systemd_can_hibernate (shutdown->systemd, can_hibernate, auth_hibernate, NULL))
+      if (xfce_systemd_can_hibernate (shutdown->systemd, can_hibernate, auth_hibernate, NULL))
         {
-          return TRUE;
+          return;
         }
     }
   else if (shutdown->consolekit != NULL)
     {
-      if (xfsm_consolekit_can_hibernate (shutdown->consolekit, can_hibernate, auth_hibernate, NULL))
+      if (xfce_consolekit_can_hibernate (shutdown->consolekit, can_hibernate, auth_hibernate, NULL))
         {
-          return TRUE;
+          return;
         }
     }
 
   *can_hibernate = xfsm_shutdown_fallback_can_hibernate ();
   *auth_hibernate = xfsm_shutdown_fallback_auth_hibernate ();
-  return TRUE;
 }
 
 
 
-gboolean
+void
 xfsm_shutdown_can_hybrid_sleep (XfsmShutdown  *shutdown,
                                 gboolean      *can_hybrid_sleep,
-                                gboolean      *auth_hybrid_sleep,
-                                GError       **error)
+                                gboolean      *auth_hybrid_sleep)
 {
-  g_return_val_if_fail (XFSM_IS_SHUTDOWN (shutdown), FALSE);
+  g_return_if_fail (XFSM_IS_SHUTDOWN (shutdown));
+
+  if (xfsm_inhibitor_has_flags (shutdown->inhibitions, XFSM_INHIBITON_FLAG_SUSPEND))
+    {
+      *can_hybrid_sleep = FALSE;
+      return;
+    }
 
   if (!xfsm_shutdown_kiosk_can_shutdown (shutdown, NULL))
     {
       *can_hybrid_sleep = FALSE;
-      return TRUE;
+      return;
     }
 
   if (shutdown->systemd != NULL)
     {
-      if (xfsm_systemd_can_hybrid_sleep (shutdown->systemd, can_hybrid_sleep, auth_hybrid_sleep, NULL))
+      if (xfce_systemd_can_hybrid_sleep (shutdown->systemd, can_hybrid_sleep, auth_hybrid_sleep, NULL))
         {
-          return TRUE;
+          return;
         }
     }
   else if (shutdown->consolekit != NULL)
     {
-      if (xfsm_consolekit_can_hybrid_sleep (shutdown->consolekit, can_hybrid_sleep, auth_hybrid_sleep, NULL))
+      if (xfce_consolekit_can_hybrid_sleep (shutdown->consolekit, can_hybrid_sleep, auth_hybrid_sleep, NULL))
         {
-          return TRUE;
+          return;
         }
     }
 
   *can_hybrid_sleep = xfsm_shutdown_fallback_can_hybrid_sleep ();
   *auth_hybrid_sleep = xfsm_shutdown_fallback_auth_hybrid_sleep ();
-  return TRUE;
 }
 
 
@@ -581,6 +671,10 @@ xfsm_shutdown_can_switch_user (XfsmShutdown  *shutdown,
   *can_switch_user = FALSE;
 
   g_return_val_if_fail (XFSM_IS_SHUTDOWN (shutdown), FALSE);
+  if (xfsm_inhibitor_has_flags (shutdown->inhibitions, XFSM_INHIBITON_FLAG_SWITCH))
+    {
+      return TRUE;
+    }
 
   if (DBUS_OBJECT_PATH == NULL)
     {
@@ -624,3 +718,35 @@ xfsm_shutdown_can_save_session (XfsmShutdown *shutdown)
   g_return_val_if_fail (XFSM_IS_SHUTDOWN (shutdown), FALSE);
   return shutdown->kiosk_can_save_session;
 }
+
+
+
+gboolean
+xfsm_shutdown_can_logout (XfsmShutdown  *shutdown)
+{
+  g_return_val_if_fail (XFSM_IS_SHUTDOWN (shutdown), FALSE);
+  return !xfsm_inhibitor_has_flags (shutdown->inhibitions,
+                                    XFSM_INHIBITON_FLAG_LOGOUT);
+}
+
+
+
+gboolean
+xfsm_shutdown_has_update_prepared (XfsmShutdown *shutdown)
+{
+  gboolean  has_updates = FALSE;
+  GError   *error = NULL;
+
+  g_return_val_if_fail (XFSM_IS_SHUTDOWN (shutdown), FALSE);
+
+  if (shutdown->systemd == NULL)
+    return FALSE;
+
+  if (!xfsm_packagekit_has_update_prepared (shutdown->packagekit, &has_updates, &error))
+    {
+      g_warning ("Querying PackageKit updates failed: %s", error->message);
+      g_error_free (error);
+    }
+
+  return has_updates;
+}
