@@ -22,6 +22,8 @@
 #ifndef __XFSM_SHUTDOWN_H__
 #define __XFSM_SHUTDOWN_H__
 
+#define LOGIND_RUNNING() (access ("/run/systemd/seats/", F_OK) >= 0)
+
 typedef struct _XfsmShutdownClass XfsmShutdownClass;
 typedef struct _XfsmShutdown      XfsmShutdown;
 
@@ -86,34 +88,34 @@ gboolean      xfsm_shutdown_try_hybrid_sleep (XfsmShutdown      *shutdown,
 gboolean      xfsm_shutdown_try_switch_user  (XfsmShutdown      *shutdown,
                                               GError           **error);
 
-gboolean      xfsm_shutdown_can_restart      (XfsmShutdown      *shutdown,
+void          xfsm_shutdown_can_restart      (XfsmShutdown      *shutdown,
                                               gboolean          *can_restart,
-                                              GError           **error);
+                                              gboolean          *auth_restart);
 
-gboolean      xfsm_shutdown_can_shutdown     (XfsmShutdown      *shutdown,
+void          xfsm_shutdown_can_shutdown     (XfsmShutdown      *shutdown,
                                               gboolean          *can_shutdown,
-                                              GError           **error);
+                                              gboolean          *auth_shutdown);
 
-gboolean      xfsm_shutdown_can_suspend      (XfsmShutdown      *shutdown,
+void          xfsm_shutdown_can_suspend      (XfsmShutdown      *shutdown,
                                               gboolean          *can_suspend,
-                                              gboolean          *auth_suspend,
-                                              GError           **error);
+                                              gboolean          *auth_suspend);
 
-gboolean      xfsm_shutdown_can_hibernate    (XfsmShutdown      *shutdown,
+void          xfsm_shutdown_can_hibernate    (XfsmShutdown      *shutdown,
                                               gboolean          *can_hibernate,
-                                              gboolean          *auth_hibernate,
-                                              GError           **error);
+                                              gboolean          *auth_hibernate);
 
-gboolean      xfsm_shutdown_can_hybrid_sleep (XfsmShutdown      *shutdown,
+void          xfsm_shutdown_can_hybrid_sleep (XfsmShutdown      *shutdown,
                                               gboolean          *can_hybrid_sleep,
-                                              gboolean          *auth_hybrid_sleep,
-                                              GError           **error);
+                                              gboolean          *auth_hybrid_sleep);
 
 gboolean      xfsm_shutdown_can_switch_user  (XfsmShutdown      *shutdown,
                                               gboolean          *can_switch_user,
                                               GError           **error);
 
-
 gboolean      xfsm_shutdown_can_save_session (XfsmShutdown      *shutdown);
 
+gboolean      xfsm_shutdown_can_logout       (XfsmShutdown      *shutdown);
+
+gboolean      xfsm_shutdown_has_update_prepared (XfsmShutdown   *shutdown);
+
 #endif	/* !__XFSM_SHUTDOWN_H__ */
